@@ -6,7 +6,10 @@ from .actions import (
     easy_ocr,
     simple_translate,
     meme_gen,
+    pic_translate,
     web_screenshot,
+    handwrite_ocr,
+    table_ocr,
     create_folder,
     create,
     find,
@@ -14,4 +17,4 @@ from .actions import (
 )
 
 # from .actions import *
-from .base import start
+from .base import start, env
